slepc-3.18.0 2022-10-01
Report Typos and Errors

# MFNAppendOptionsPrefix

Appends to the prefix used for searching for all MFN options in the database.

### Synopsis

    #include "slepcmfn.h"
    PetscErrorCode MFNAppendOptionsPrefix(MFN mfn,const char *prefix)

Logically Collective on mfn

### Input Parameters

| mfn | - the matrix function context
| prefix | - the prefix string to prepend to all MFN option requests

### Notes

A hyphen (-) must NOT be given at the beginning of the prefix name. The first character of all runtime options is AUTOMATICALLY the hyphen.

### See Also

MFNSetOptionsPrefix(), MFNGetOptionsPrefix()

### Level

advanced

### Location

src/mfn/interface/mfnopts.c
Index of all MFN routines
Table of Contents for all manual pages
Index of all manual pages